(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     73275,       1888]*)
(*NotebookOutlinePosition[     73966,       1912]*)
(*  CellTagsIndexPosition[     73922,       1908]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["chargecharge", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["chargecharge[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["d", "TI"],
  StyleBox["]", "MR"],
  " returns the charge-charge repulsion operator between the levels described \
by the operators ",
  StyleBox["c", "TI"],
  " and ",
  StyleBox["d", "TI"],
  "."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] Operators ",
  StyleBox["c", "TI",
    FontSize->10],
  " and ",
  StyleBox["d", "TI"],
  " must be expressed in a form which excludes the first index \
(creation/annihilation) and the last index (spin). "
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["hubbard",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["spinspin",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " and ",
  StyleBox["d", "TI"],
  " to be fermionic operators"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c, d];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[TextData[{
  "Electron repulsion interaction between the levels described by the \
operators ",
  StyleBox["c", "IT"],
  " and ",
  StyleBox["d", "IT"],
  "."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(H = chargecharge[c[], d[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    TagBox[\(chargecharge[c[], d[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
Charge-charge interaction commutes with the total spin \
operators\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({S\_x, S\_y, S\_z, S2} = 
        manyspin[{c[], d[]}];\)\), "\[IndentingNewLine]", 
    \(komutator[H, S\_x] \[Equal] 0 // ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[H, S\_y] \[Equal] 0 // ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[H, S\_z] \[Equal] 0 // ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[H, S2] \[Equal] 0 // ExpandAll\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "Charge-charge interaction commutes with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(I\_z\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`I\^2\)]],
  " isospin operators, but not with ",
  Cell[BoxData[
      \(TraditionalForm\`I\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`I\_y\)]],
  "."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({I\_x, I\_y, I\_z, I2} = 
      manyisospin[{c[], d[]}]\), "\[IndentingNewLine]", 
    \(komutator[H, I\_x] =!= 0 // ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[H, I\_y] =!= 0 // ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[H, I\_z] == 0 // ExpandAll\), "\n", 
    \(komutator[H, I2] == 0 // ExpandAll\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(-\(1\/2\)\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{\(-1\), "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{"2", "-", 
          RowBox[{\(5\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(5\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(5\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(5\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(3\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{\(3\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}]}], "}"}]], "Output",
  CellLabel->"Out[10]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[11]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 279}, {189, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 38, "ObjectName"],
Cell[1813, 55, 346, 13, 48, "Usage"],
Cell[2162, 70, 258, 8, 40, "Notes"],
Cell[2423, 80, 190, 8, 24, "Notes"],

Cell[CellGroupData[{
Cell[2638, 92, 42, 0, 38, "ExampleSection"],
Cell[2683, 94, 150, 6, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[2858, 104, 142, 3, 42, "Input"],
Cell[3003, 109, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3121, 114, 182, 7, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3328, 125, 134, 3, 42, "Input"],
Cell[3465, 130, 11997, 323, 58, "Output"],
Cell[15465, 455, 104, 3, 25, "Output"]
}, Open  ]],
Cell[15584, 461, 97, 3, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[15706, 468, 420, 7, 92, "Input"],
Cell[16129, 477, 62, 2, 25, "Output"],
Cell[16194, 481, 62, 2, 25, "Output"],
Cell[16259, 485, 62, 2, 25, "Output"],
Cell[16324, 489, 62, 2, 25, "Output"]
}, Open  ]],
Cell[16401, 494, 364, 14, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[16790, 512, 378, 7, 92, "Input"],
Cell[17171, 521, 55800, 1346, 261, "Output"],
Cell[72974, 1869, 63, 2, 25, "Output"],
Cell[73040, 1873, 63, 2, 25, "Output"],
Cell[73106, 1877, 63, 2, 25, "Output"],
Cell[73172, 1881, 63, 2, 25, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

