(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7316,        245]*)
(*NotebookOutlinePosition[      8253,        279]*)
(*  CellTagsIndexPosition[      8156,        272]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["hubbard", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["hubbard[", "MR"],
  StyleBox["c", "TI"],
  StyleBox["]", "MR"],
  " returns the local (Hubbard) electron-electron repulsion operator for the \
level described by the operator ",
  StyleBox["c", "TI"],
  ".\n\[FilledSmallSquare] ",
  StyleBox["isozsq[", "MR"],
  StyleBox["c", "IT"],
  StyleBox["]", "MR"],
  " returns the z-component of the on-site isospin operator squared. This \
term appears in the expression for electron-electron repulsion in the Anderon \
model."
}], "Usage",
  CellTags->{"hubbard", "isozsq"}],

Cell[TextData[{
  "\[FilledSmallSquare] Operator ",
  StyleBox["c", "TI",
    FontSize->10],
  " must be expressed in the stripped form, i.e. a form which excludes the \
first index (creation/annihilation) and the last index (spin). "
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["isozsq",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["number",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["pow",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["chargecharge",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " to be a fermionic operator"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Verify the definition", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(H = hubbard[c[]]\), "\[IndentingNewLine]", 
    \(H \[Equal] nc[number[c[], CR], number[c[], AN]]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "Relation with ",
  ButtonBox["chargecharge",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["isozsq",
    ButtonStyle->"AddOnsLink"]
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(chargecharge[c[], c[]] \[Equal] 
      number[c[]] + 2\ hubbard[c[]]\), "\[IndentingNewLine]", 
    \(isozsq[c[]] == 1 - number[c[]] + 2  hubbard[c[]]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 573}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "hubbard"->{
    Cell[1808, 55, 572, 16, 86, "Usage",
      CellTags->{"hubbard", "isozsq"}]},
  "isozsq"->{
    Cell[1808, 55, 572, 16, 86, "Usage",
      CellTags->{"hubbard", "isozsq"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"hubbard", 7953, 262},
  {"isozsq", 8049, 265}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 29, 0, 38, "ObjectName"],
Cell[1808, 55, 572, 16, 86, "Usage",
  CellTags->{"hubbard", "isozsq"}],
Cell[2383, 73, 247, 6, 40, "Notes"],
Cell[2633, 81, 314, 14, 24, "Notes"],

Cell[CellGroupData[{
Cell[2972, 99, 42, 0, 38, "ExampleSection"],
Cell[3017, 101, 117, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3159, 109, 139, 3, 42, "Input"],
Cell[3301, 114, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3419, 119, 44, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3488, 123, 156, 3, 42, "Input"],
Cell[3647, 128, 3007, 82, 33, "Output"],
Cell[6657, 212, 62, 2, 25, "Output"]
}, Open  ]],
Cell[6734, 217, 178, 7, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[6937, 228, 209, 4, 42, "Input"],
Cell[7149, 234, 62, 2, 25, "Output"],
Cell[7214, 238, 62, 2, 25, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

