(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    632817,      14753]*)
(*NotebookOutlinePosition[    633469,      14776]*)
(*  CellTagsIndexPosition[    633425,      14772]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Double quantum dot with interimpurity charge-charge repulsion term
Part of SNEG package, http://nrgljubljana.ijs.si
Rok Zitko, rok.zitko@ijs.si, March 2007\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"],

Cell[BoxData[
    \("sneg 1.167 Copyright (C) 2007 Rok Zitko"\)], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(snegfermionoperators[d]\), "\[IndentingNewLine]", 
    \(snegrealconstants[U, U12, t, \[Delta]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(H = 
        Sum[\[Delta]\ \((number[d[i]] - 1)\) + 
              U/2\ \((pow[number[d[i]] - 1, 2])\), {i, 2}] + 
          U12\ chargecharge[d[1], d[2]] + 
          t\ hop[d[1], d[2]];\)\), "\[IndentingNewLine]", 
    \(Collect[H, Cases[H, _nc, {1, \[Infinity]}]]\)}], "Input"],

Cell[BoxData[
    RowBox[{"U", "-", \(2\ \[Delta]\), "+", 
      RowBox[{\((\(-\(U\/2\)\) + \[Delta])\), " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\((\(-\(U\/2\)\) + \[Delta])\), " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\((\(-\(U\/2\)\) + \[Delta])\), " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\((\(-\(U\/2\)\) + \[Delta])\), " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U12", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U12", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U12", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U12", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({sx, sy, sz, stot} = manyspin[{d[1], d[2]}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{
          RowBox[{\(-\(1\/2\)\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{
          RowBox[{\(3\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(3\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(3\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(3\/4\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(3\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(3\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({ox, oy, 
        oz} = \(Sum[
            Expand[nc[d[CR, i, \[Mu]], 1/2  #[\([i, j]\)], 
                d[AN, j, \[Mu]]]], {i, 2}, {j, 2}, {\[Mu], 0, 
              1}] &\)\  /@ {PauliX, PauliY, PauliZ}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{
          RowBox[{\(-\(\[ImaginaryI]\/2\)\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(\[ImaginaryI]\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ",", 
        RowBox[{
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{\(1\/2\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["Spin and pseudo-spin operators commute!", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand\ @\ Outer[\ komutator, {sx, sy, sz}, {ox, oy, oz}]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["Hamiltonian commutes with spin operator for any parameters.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Expand\ @\ komutator[H, sx]\), "\[IndentingNewLine]", 
    \(Expand\ @\ komutator[H, sy]\), "\[IndentingNewLine]", 
    \(Expand\ @\ komutator[H, sz]\)}], "Input"],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
Orbital psuedo-spin operators commute with the Hamiltonian for \
U=U12 and t=0.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Expand\ @\ komutator[H, ox]\), "\n", 
    \(% /. U12 \[Rule] U\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(1\/2\)\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Expand\ @\ komutator[H, oy]\), "\n", 
    \(% /. U12 \[Rule] U\), "\[IndentingNewLine]", 
    \(% /. t \[Rule] 0\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(1\/2\), " ", "\[ImaginaryI]", " ", "U12", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Expand\ @\ komutator[H, oz]\), "\[IndentingNewLine]", 
    \(% /. t \[Rule] 0\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-t\), " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{"t", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["Hamiltonian without hopping for U12=U.", "Text"],

Cell[BoxData[
    \(\(H2 = H /. {t \[Rule] 0, U12 \[Rule] U};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdt = Outer[nc, {sx, sy, sz}, {ox, oy, oz}] // Expand\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ",", 
            RowBox[{
              RowBox[{\(-\(\[ImaginaryI]\/4\)\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ",", 
            RowBox[{
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ",", 
            RowBox[{
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ",", 
            RowBox[{
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(-\(1\/4\)\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ",", 
            RowBox[{
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(\[ImaginaryI]\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ",", 
            RowBox[{
              RowBox[{\(-\(1\/4\)\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/4\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{\(1\/2\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{\(1\/2\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Hamiltonian\ \((for\ U12 = \(U\ and\ t = 
            0\))\)\ commutes\ with\ direct\ product\ operators\ \(S\_i\) 
      O\_j\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Expand\ @\ komutator[H2, #] &, Flatten[pdt]]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["We add factors of 2 to simplify matrices", "Text"],

Cell[BoxData[
    \(\(t = 
        2  Join[{sx, sy, sz}, {ox, oy, oz}, 2  Flatten[pdt]];\)\)], "Input"],

Cell["\<\
Defining SU(4) quadruplet representation. (cf Georgi, p. 114)\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(quadruplet = {d[CR, 1, UP], d[CR, 1, DO], d[CR, 2, UP], 
        d[CR, 2, DO]}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(braketop[a_, op_, b_] := scalarproductop[a, nc[op, b]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(braketop[1, 1, 1]\), "\[IndentingNewLine]", 
    \(braketop[d[CR, 1, UP], 1, d[CR, 1, UP]]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MatrixForm\ @\ 
          Table[braketop[quadruplet[\([i]\)], #, quadruplet[\([j]\)]]\ , {i, 
              4}, {j, 4}] &\) /@ {2  sx, 2  sy, 2  sz}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"},
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", \(-\[ImaginaryI]\), "0", "0"},
                {"\[ImaginaryI]", "0", "0", "0"},
                {"0", "0", "0", \(-\[ImaginaryI]\)},
                {"0", "0", "\[ImaginaryI]", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", \(-1\), "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", \(-1\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MatrixForm\ @\ 
          Table[braketop[quadruplet[\([i]\)], #, quadruplet[\([j]\)]]\ , {i, 
              4}, {j, 4}] &\) /@ {2  ox, 2  oy, 2  oz}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"},
                {"1", "0", "0", "0"},
                {"0", "1", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", \(-\[ImaginaryI]\), "0"},
                {"0", "0", "0", \(-\[ImaginaryI]\)},
                {"\[ImaginaryI]", "0", "0", "0"},
                {"0", "\[ImaginaryI]", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "1", "0", "0"},
                {"0", "0", \(-1\), "0"},
                {"0", "0", "0", \(-1\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = \ \(Table[
              braketop[quadruplet[\([i]\)], #, quadruplet[\([j]\)]]\ , {i, 
                4}, {j, 4}] &\) /@ t;\)\), "\[IndentingNewLine]", 
    \(MatrixForm\  /@ \ m\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"},
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", \(-\[ImaginaryI]\), "0", "0"},
                {"\[ImaginaryI]", "0", "0", "0"},
                {"0", "0", "0", \(-\[ImaginaryI]\)},
                {"0", "0", "\[ImaginaryI]", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", \(-1\), "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", \(-1\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"},
                {"1", "0", "0", "0"},
                {"0", "1", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", \(-\[ImaginaryI]\), "0"},
                {"0", "0", "0", \(-\[ImaginaryI]\)},
                {"\[ImaginaryI]", "0", "0", "0"},
                {"0", "\[ImaginaryI]", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "1", "0", "0"},
                {"0", "0", \(-1\), "0"},
                {"0", "0", "0", \(-1\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", \(-\[ImaginaryI]\)},
                {"0", "0", \(-\[ImaginaryI]\), "0"},
                {"0", "\[ImaginaryI]", "0", "0"},
                {"\[ImaginaryI]", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"},
                {"0", "0", "0", \(-1\)},
                {"0", "0", \(-1\), "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", \(-\[ImaginaryI]\)},
                {"0", "0", "\[ImaginaryI]", "0"},
                {"0", \(-\[ImaginaryI]\), "0", "0"},
                {"\[ImaginaryI]", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", \(-1\)},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"},
                {\(-1\), "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", \(-\[ImaginaryI]\), "0", "0"},
                {"\[ImaginaryI]", "0", "0", "0"},
                {"0", "0", "0", "\[ImaginaryI]"},
                {"0", "0", \(-\[ImaginaryI]\), "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1", "0"},
                {"0", "0", "0", \(-1\)},
                {"1", "0", "0", "0"},
                {"0", \(-1\), "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", \(-\[ImaginaryI]\), "0"},
                {"0", "0", "0", "\[ImaginaryI]"},
                {"\[ImaginaryI]", "0", "0", "0"},
                {"0", \(-\[ImaginaryI]\), "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", \(-1\), "0", "0"},
                {"0", "0", \(-1\), "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell["Traceless matrices with det=1", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Det, m]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Tr, m]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Outer[Tr[#1 . #2] &, m, m, 1]\)], "Input"],

Cell[BoxData[
    \({{4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 4, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0}, {0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 4, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 
        0, 0}, {0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
        0, 0, 4, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 
        0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        4, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, {0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 4}}\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sextuplet = {\[IndentingNewLine]nc[d[CR, 1, UP], 
          d[CR, 2, UP]], \[IndentingNewLine]1/
            Sqrt[2] \((nc[d[CR, 1, UP], d[CR, 2, DO]] + 
              nc[d[CR, 1, DO], d[CR, 2, UP]])\), \[IndentingNewLine]nc[
          d[CR, 1, DO], d[CR, 2, DO]], \[IndentingNewLine]nc[d[CR, 1, UP], 
          d[CR, 1, DO]], \[IndentingNewLine]1/
            Sqrt[2] \((nc[d[CR, 1, UP], d[CR, 2, DO]] - 
              nc[d[CR, 1, DO], d[CR, 2, UP]])\), \[IndentingNewLine]nc[
          d[CR, 2, UP], d[CR, 2, DO]]}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ",", 
        FractionBox[
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], \(\@2\)], ",", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ",", 
        RowBox[{"\<\"-\"\>", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ",", 
        FractionBox[
          RowBox[{
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["d", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ d, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["d", 
                        RowBox[{"2", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ d, 
                        RowBox[ {2, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], \(\@2\)], ",", 
        RowBox[{"\<\"-\"\>", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = \ \(Table[
              braketop[sextuplet[\([i]\)], #, sextuplet[\([j]\)]]\ , {i, 
                6}, {j, 6}] &\) /@ t;\)\), "\[IndentingNewLine]", 
    \(MatrixForm\  /@ \ m\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", \(\@2\), "0", "0", "0", "0"},
                {\(\@2\), "0", \(\@2\), "0", "0", "0"},
                {"0", \(\@2\), "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", \(\(-\[ImaginaryI]\)\ \@2\), "0", "0", "0", "0"},
                {\(\[ImaginaryI]\ \@2\), "0", \(\(-\[ImaginaryI]\)\ \@2\), 
                  "0", "0", "0"},
                {"0", \(\[ImaginaryI]\ \@2\), "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", \(-2\), "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", \(\@2\), "0"},
                {"0", "0", "0", \(\@2\), "0", \(\@2\)},
                {"0", "0", "0", "0", \(\@2\), "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", \(\(-\[ImaginaryI]\)\ \@2\), "0"},
                {"0", "0", "0", \(\[ImaginaryI]\ \@2\), 
                  "0", \(\(-\[ImaginaryI]\)\ \@2\)},
                {"0", "0", "0", "0", \(\[ImaginaryI]\ \@2\), "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "2", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", \(-2\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Det, m]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Tr, m]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Outer[Tr[#1 . #2] &, m, m, 1]\)], "Input"],

Cell[BoxData[
    \({{8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 8, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0}, {0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 8, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 
        0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{871, 880},
WindowMargins->{{Automatic, 101}, {Automatic, 74}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 214, 5, 84, "Text"],

Cell[CellGroupData[{
Cell[1993, 60, 112, 2, 43, "Input"],
Cell[2108, 64, 74, 1, 23, "Print"]
}, Open  ]],
Cell[2197, 68, 130, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[2352, 74, 303, 6, 59, "Input"],
Cell[2658, 82, 33421, 861, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36116, 948, 76, 1, 27, "Input"],
Cell[36195, 951, 59101, 1408, 192, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95333, 2364, 238, 5, 43, "Input"],
Cell[95574, 2371, 22346, 533, 81, "Output"]
}, Open  ]],
Cell[117935, 2907, 55, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[118015, 2911, 90, 1, 27, "Input"],
Cell[118108, 2914, 67, 1, 27, "Output"]
}, Open  ]],
Cell[118190, 2918, 75, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[118290, 2922, 184, 3, 59, "Input"],
Cell[118477, 2927, 35, 1, 27, "Output"],
Cell[118515, 2930, 35, 1, 27, "Output"],
Cell[118553, 2933, 35, 1, 27, "Output"]
}, Open  ]],
Cell[118603, 2937, 103, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[118731, 2944, 97, 2, 43, "Input"],
Cell[118831, 2948, 53759, 1376, 155, "Output"],
Cell[172593, 4326, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172665, 4332, 147, 3, 59, "Input"],
Cell[172815, 4337, 60787, 1547, 229, "Output"],
Cell[233605, 5886, 6714, 172, 35, "Output"],
Cell[240322, 6060, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240394, 6066, 112, 2, 43, "Input"],
Cell[240509, 6070, 6591, 171, 35, "Output"],
Cell[247103, 6243, 35, 1, 27, "Output"]
}, Open  ]],
Cell[247153, 6247, 54, 0, 32, "Text"],
Cell[247210, 6249, 76, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[247311, 6254, 86, 1, 27, "Input"],
Cell[247400, 6257, 343756, 7395, 904, "Output"]
}, Open  ]],
Cell[591171, 13655, 158, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[591354, 13662, 81, 1, 27, "Input"],
Cell[591438, 13665, 61, 1, 27, "Output"]
}, Open  ]],
Cell[591514, 13669, 56, 0, 32, "Text"],
Cell[591573, 13671, 103, 2, 27, "Input"],
Cell[591679, 13675, 87, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[591791, 13682, 111, 2, 27, "Input"],
Cell[591905, 13686, 2990, 80, 35, "Output"]
}, Open  ]],
Cell[594910, 13769, 92, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[595027, 13774, 125, 2, 43, "Input"],
Cell[595155, 13778, 35, 1, 27, "Output"],
Cell[595193, 13781, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[595265, 13787, 183, 3, 27, "Input"],
Cell[595451, 13792, 1428, 38, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596916, 13835, 183, 3, 27, "Input"],
Cell[597102, 13840, 1428, 38, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[598567, 13883, 220, 4, 43, "Input"],
Cell[598790, 13889, 6960, 182, 247, "Output"]
}, Open  ]],
Cell[605765, 14074, 45, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[605835, 14078, 44, 1, 27, "Input"],
Cell[605882, 14081, 79, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[605998, 14087, 43, 1, 27, "Input"],
Cell[606044, 14090, 79, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[606160, 14096, 62, 1, 27, "Input"],
Cell[606225, 14099, 829, 11, 139, "Output"]
}, Open  ]],
Cell[607069, 14113, 283, 9, 10, "Text"],

Cell[CellGroupData[{
Cell[607377, 14126, 549, 9, 123, "Input"],
Cell[607929, 14137, 14470, 351, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[622436, 14493, 218, 4, 43, "Input"],
Cell[622657, 14499, 8888, 214, 529, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631582, 14718, 44, 1, 27, "Input"],
Cell[631629, 14721, 79, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631745, 14727, 43, 1, 27, "Input"],
Cell[631791, 14730, 79, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631907, 14736, 62, 1, 27, "Input"],
Cell[631972, 14739, 829, 11, 139, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

